@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import copy
 from dataclasses import dataclass
 from datetime import datetime, timezone
@@ -17,7 +19,10 @@ class CachedSceneException(Arcor2Exception):
 
 
 class CachedBase:
-    def __init__(self, data: Union[cmn.Scene, cmn.Project]) -> None:
+
+    __slots__ = "id", "name", "description", "created", "modified", "int_modified"
+
+    def __init__(self, data: Union[cmn.Scene, cmn.Project, CachedScene, CachedProject]) -> None:
 
         self.id: str = data.id
         self.name: str = data.name
@@ -25,17 +30,19 @@ class CachedBase:
 
         self.created: Optional[datetime] = data.created
         self.modified: Optional[datetime] = data.modified
-        self._int_modified: Optional[datetime] = data.int_modified
+        self.int_modified: Optional[datetime] = data.int_modified
 
 
 class UpdateableMixin:
 
+    __slots__ = ()
+
     if TYPE_CHECKING:
         modified: Optional[datetime] = None
-        _int_modified: Optional[datetime] = None
+        int_modified: Optional[datetime] = None
 
     def update_modified(self) -> None:
-        self._int_modified = datetime.now(tz=timezone.utc)
+        self.int_modified = datetime.now(tz=timezone.utc)
 
     @property
     def has_changes(self) -> bool:
@@ -50,33 +57,40 @@ class UpdateableMixin:
             return True
 
         # this is true for scene/project that was loaded but there are not changes yet
-        if self._int_modified is None:
+        if self.int_modified is None:
             return False
 
         # if the scene/project was already saved once (modified is not None)
         # and there were some changes (int_modified is not None)
         # let's compare if some change happened (int_modified) after saving to the Project service (modified)
-        return self._int_modified > self.modified
+        return self.int_modified > self.modified
 
 
 class CachedScene(CachedBase):
-    def __init__(self, scene: cmn.Scene) -> None:
+
+    __slots__ = ("_objects",)
+
+    def __init__(self, scene: Union[cmn.Scene, CachedScene]) -> None:
 
         super().__init__(scene)
 
-        # TODO deal with children
         self._objects: Dict[str, cmn.SceneObject] = {}
 
-        for obj in scene.objects:
+        if isinstance(scene, CachedScene):
+            self._objects = scene._objects
+        else:
+            # TODO deal with children
 
-            if obj.id in self._objects:
-                raise CachedSceneException(f"Duplicate object id: {obj.id}.")
+            for obj in scene.objects:
 
-            self._objects[obj.id] = obj
+                if obj.id in self._objects:
+                    raise CachedSceneException(f"Duplicate object id: {obj.id}.")
+
+                self._objects[obj.id] = obj
 
     @property
     def bare(self) -> cmn.BareScene:
-        return cmn.BareScene(self.name, self.description, self.created, self.modified, self._int_modified, id=self.id)
+        return cmn.BareScene(self.name, self.description, self.created, self.modified, self.int_modified, id=self.id)
 
     def object_names(self) -> Iterator[str]:
 
@@ -115,13 +129,16 @@ class CachedScene(CachedBase):
 
         sc = cmn.Scene.from_bare(self.bare)
         sc.modified = self.modified
-        sc.int_modified = self._int_modified
+        sc.int_modified = self.int_modified
         sc.objects = list(self.objects)
         return sc
 
 
 class UpdateableCachedScene(UpdateableMixin, CachedScene):
-    def __init__(self, scene: cmn.Scene):
+
+    __slots__ = ()
+
+    def __init__(self, scene: Union[cmn.Scene, CachedScene]):
         super(UpdateableCachedScene, self).__init__(copy.deepcopy(scene))
 
     def upsert_object(self, obj: cmn.SceneObject) -> None:
@@ -145,26 +162,53 @@ class CachedProjectException(Arcor2Exception):
 
 @dataclass
 class Parent:
+
+    __slots__ = ("ap",)
+
     ap: cmn.BareActionPoint
 
 
 @dataclass
 class ApAction(Parent):
+
+    __slots__ = ("action",)
+
     action: cmn.Action
 
 
 @dataclass
 class ApJoints(Parent):
+
+    __slots__ = ("joints",)
+
     joints: cmn.ProjectRobotJoints
 
 
 @dataclass
 class ApOrientation(Parent):
+
+    __slots__ = ("orientation",)
+
     orientation: cmn.NamedOrientation
 
 
 class CachedProject(CachedBase):
-    def __init__(self, project: cmn.Project):
+
+    __slots__ = (
+        "scene_id",
+        "has_logic",
+        "_action_points",
+        "_actions",
+        "_joints",
+        "_orientations",
+        "_parameters",
+        "_logic_items",
+        "_functions",
+        "overrides",
+        "_childs",
+    )
+
+    def __init__(self, project: Union[cmn.Project, CachedProject]):
 
         super().__init__(project)
 
@@ -177,7 +221,7 @@ class CachedProject(CachedBase):
         self._joints: Dict[str, ApJoints] = {}
         self._orientations: Dict[str, ApOrientation] = {}
 
-        self._constants: Dict[str, cmn.ProjectParameter] = {}
+        self._parameters: Dict[str, cmn.ProjectParameter] = {}
         self._logic_items: Dict[str, cmn.LogicItem] = {}
         self._functions: Dict[str, cmn.ProjectFunction] = {}
 
@@ -185,50 +229,63 @@ class CachedProject(CachedBase):
 
         self._childs: Dict[str, Set[str]] = {}
 
-        for ap in project.action_points:
+        if isinstance(project, CachedProject):
+            self._action_points = project._action_points
+            self._actions = project._actions
+            self._joints = project._joints
+            self._orientations = project._orientations
+            self._parameters = project._parameters
+            self._logic_items = project._logic_items
+            self._functions = project._functions
+            self.overrides = project.overrides
+            self._childs = project._childs
 
-            if ap.id in self._action_points:
-                raise CachedProjectException(f"Duplicate AP id: {ap.id}.")
+        else:
 
-            bare_ap = cmn.BareActionPoint(ap.name, ap.position, ap.parent, id=ap.id)
-            self._action_points[ap.id] = bare_ap
-            self._upsert_child(ap.parent, ap.id)
+            for ap in project.action_points:
 
-            for ac in ap.actions:
+                if ap.id in self._action_points:
+                    raise CachedProjectException(f"Duplicate AP id: {ap.id}.")
 
-                if ac.id in self._actions:
-                    raise CachedProjectException(f"Duplicate action id: {ac.id}.")
+                bare_ap = cmn.BareActionPoint(ap.name, ap.position, ap.parent, id=ap.id)
+                self._action_points[ap.id] = bare_ap
+                self._upsert_child(ap.parent, ap.id)
 
-                self._actions[ac.id] = ApAction(bare_ap, ac)
-                self._upsert_child(ap.id, ac.id)
+                for ac in ap.actions:
 
-            for joints in ap.robot_joints:
+                    if ac.id in self._actions:
+                        raise CachedProjectException(f"Duplicate action id: {ac.id}.")
 
-                if joints.id in self._joints:
-                    raise CachedProjectException(f"Duplicate joints id: {joints.id}.")
+                    self._actions[ac.id] = ApAction(bare_ap, ac)
+                    self._upsert_child(ap.id, ac.id)
 
-                self._joints[joints.id] = ApJoints(bare_ap, joints)
-                self._upsert_child(ap.id, joints.id)
+                for joints in ap.robot_joints:
 
-            for orientation in ap.orientations:
+                    if joints.id in self._joints:
+                        raise CachedProjectException(f"Duplicate joints id: {joints.id}.")
 
-                if orientation.id in self._orientations:
-                    raise CachedProjectException(f"Duplicate orientation id: {orientation.id}.")
+                    self._joints[joints.id] = ApJoints(bare_ap, joints)
+                    self._upsert_child(ap.id, joints.id)
 
-                self._orientations[orientation.id] = ApOrientation(bare_ap, orientation)
-                self._upsert_child(ap.id, orientation.id)
+                for orientation in ap.orientations:
 
-        for override in project.object_overrides:
-            self.overrides[override.id] = override.parameters
+                    if orientation.id in self._orientations:
+                        raise CachedProjectException(f"Duplicate orientation id: {orientation.id}.")
 
-        for constant in project.parameters:
-            self._constants[constant.id] = constant
+                    self._orientations[orientation.id] = ApOrientation(bare_ap, orientation)
+                    self._upsert_child(ap.id, orientation.id)
 
-        for logic_item in project.logic:
-            self._logic_items[logic_item.id] = logic_item
+            for override in project.object_overrides:
+                self.overrides[override.id] = override.parameters
 
-        for function in project.functions:
-            self._functions[function.id] = function
+            for param in project.parameters:
+                self._parameters[param.id] = param
+
+            for logic_item in project.logic:
+                self._logic_items[logic_item.id] = logic_item
+
+            for function in project.functions:
+                self._functions[function.id] = function
 
     @property
     def logic(self) -> ValuesView[cmn.LogicItem]:
@@ -239,12 +296,12 @@ class CachedProject(CachedBase):
         return {cmn.LogicItem.START, cmn.LogicItem.END} | self._logic_items.keys()
 
     @property
-    def constants(self) -> ValuesView[cmn.ProjectParameter]:
-        return self._constants.values()
+    def parameters(self) -> ValuesView[cmn.ProjectParameter]:
+        return self._parameters.values()
 
     @property
-    def constants_ids(self) -> Set[str]:
-        return set(self._constants)
+    def parameters_ids(self) -> Set[str]:
+        return set(self._parameters)
 
     @property
     def functions(self) -> ValuesView[cmn.ProjectFunction]:
@@ -264,7 +321,7 @@ class CachedProject(CachedBase):
             proj.action_points.append(ap)
 
         proj.object_overrides = [cmn.SceneObjectOverride(k, v) for k, v in self.overrides.items()]
-        proj.parameters = list(self.constants)
+        proj.parameters = list(self.parameters)
         proj.functions = list(self.functions)
         proj.logic = list(self.logic)
         return proj
@@ -278,7 +335,7 @@ class CachedProject(CachedBase):
             self.has_logic,
             self.created,
             self.modified,
-            self._int_modified,
+            self.int_modified,
             id=self.id,
         )
 
@@ -451,12 +508,17 @@ class CachedProject(CachedBase):
         except KeyError:
             raise CachedProjectException("LogicItem not found.")
 
-    def constant(self, constant_id: str) -> cmn.ProjectParameter:
+    def parameter(self, parameter_id: str) -> cmn.ProjectParameter:
+        """Gets a project parameter by its ID.
+
+        :param parameter_id:
+        :return:
+        """
 
         try:
-            return self._constants[constant_id]
+            return self._parameters[parameter_id]
         except KeyError:
-            raise CachedProjectException("Constant not found.")
+            raise CachedProjectException("Project parameter not found.")
 
     def get_by_id(
         self, obj_id: str
@@ -470,8 +532,8 @@ class CachedProject(CachedBase):
             return self._orientations[obj_id].orientation
         elif obj_id in self._actions:  # Action
             return self._actions[obj_id].action
-        elif obj_id in self._constants:
-            return self._constants[obj_id]
+        elif obj_id in self._parameters:
+            return self._parameters[obj_id]
 
         raise CachedProjectException("Object not found.")
 
@@ -514,8 +576,11 @@ class CachedProject(CachedBase):
 
 
 class UpdateableCachedProject(UpdateableMixin, CachedProject):
-    def __init__(self, project: cmn.Project):
-        super(UpdateableCachedProject, self).__init__(copy.deepcopy(project))
+
+    __slots__ = ()
+
+    def __init__(self, project: Union[cmn.Project, CachedProject]):
+        super().__init__(copy.deepcopy(project))
 
     def upsert_action(self, ap_id: str, action: cmn.Action) -> None:
 
@@ -656,15 +721,15 @@ class UpdateableCachedProject(UpdateableMixin, CachedProject):
         self._logic_items.clear()
         self.update_modified()
 
-    def upsert_constant(self, const: cmn.ProjectParameter) -> None:
-        self._constants[const.id] = const
+    def upsert_parameter(self, parameter: cmn.ProjectParameter) -> None:
+        self._parameters[parameter.id] = parameter
         self.update_modified()
 
-    def remove_constant(self, const_id: str) -> cmn.ProjectParameter:
+    def remove_parameter(self, parameter_id: str) -> cmn.ProjectParameter:
 
         try:
-            const = self._constants.pop(const_id)
+            param = self._parameters.pop(parameter_id)
         except KeyError as e:
-            raise CachedProjectException("Constant not found.") from e
+            raise CachedProjectException("Project parameter not found.") from e
         self.update_modified()
-        return const
+        return param
